---
sidebar_position: 6
---

# Special Win System

## Overview
Special Wins are high-value reward events categorized by payout thresholds:

| Win Type | Trigger Threshold | Preview |
|----------|-------------------|---------|
| **Big Win** | Medium payout | ![Big Win](../img/05-main-scene/special-win-big.png) |
| **Super Win** | High payout | ![Super Win](../img/05-main-scene/special-win-super.png) |
| **Mega Win** | Maximum payout | ![Mega Win](../img/05-main-scene/special-win-mega.png) |

## Implementation
### Asset Preparation
- Components:
  | Component | Purpose |
  |-----------|---------|
  | `hyper-special-win-initializer` | Initializes the system. |
  | `hyper-present-special-win` | Manages animation sequences and display logic. |
  | `hyper-special-win-label-point-effect` | Controls win amount visualization. |
  - ![Component Architecture](../img/05-main-scene/special-win-in-game.png)

- **Coin Effect System**:
  - Variants for different game theme:
    | Submodule | Theme | Preview |
    |-----------|-------|---------|
    | `hyper-coin-shower-international` | International | ![International Coin](../img/05-main-scene/special-win-coin-international.png) |
    | `hyper-coin-shower-chinese` | Chinese | ![Chinese Coin](../img/05-main-scene/special-win-coin-chinese.png) |

- **Static Assets**:
  | Platform | Path | Preview |
  |----------|------|---------|
  | Desktop | `assets/textures/desktop/preloads/special-wins` | ![Desktop Assets](../img/05-main-scene/special-win-folder-desktop.png) |
  | Mobile | `assets/textures/mobile/preloads/special-wins` | ![Mobile Assets](../img/05-main-scene/special-win-folder-mobile.png) |

### Animation Setup
1. **Animation Resources**:
   - Path:
     | Platform | Path | Preview |
     |----------|------|---------|
     | Desktop | `assets/textures/desktop/postloads/anim-special-win` | ![Desktop Animation](../img/05-main-scene/special-win-folder-desktop-anim.png) |
     | Mobile | `assets/textures/mobile/postloads/anim-special-win` | ![Mobile Animation](../img/05-main-scene/special-win-folder-mobile-anim.png) |

2. **Animation Flow**:
   ```mermaid
   graph TD
       SW[Special Wins] --> BW[Big Win]
       SW --> SPW[Super Win]
       SW --> MW[Mega Win]

       BW --> BWI[bigwin-in] --> BWL[bigwin-loop] --> BWO[bigwin-out]
       SPW --> SPWI[superwin-in] --> SPWL[superwin-loop] --> SPWO[superwin-out]
       MW --> MWI[megawin-in] --> MWL[megawin-loop] --> MWO[megawin-out]

       classDef inStage fill:#e6f3ff,stroke:#666,color:#000
       classDef loopStage fill:#fff2cc,stroke:#666,color:#000
       classDef outStage fill:#f8cecc,stroke:#666,color:#000
       classDef winType fill:#d5e8d4,stroke:#82b366,color:#000
       classDef specialWin fill:#fff4dd,stroke:#ff0000,color:#000

       class BWI,SPWI,MWI inStage
       class BWL,SPWL,MWL loopStage
       class BWO,SPWO,MWO outStage
       class BW,SPW,MW winType
       class SW specialWin
       linkStyle default stroke-width:2px,stroke:#ff0000
   ```
   - ![Type Names](../img/05-main-scene/special-win-type-name.png)

3. **Animation Settings**:
   - Configure static fallback and loop animations:
     | Setting | Example |
     |---------|---------|
     | Static Fallback | ![Static Fallback](../img/05-main-scene/special-win-static.png) |
     | Loop Animation | ![Loop Animation](../img/05-main-scene/special-win-loop.png) |

4. **Font Configuration**:
   - Path: `assets/game-assets/fonts/preloads/main-game/fnt-special-win`
   - Steps:
     1. Import font files.
        - ![Font Packaging](../img/05-main-scene/special-win-pack-font.png)
     2. Add font to the special win component.
        - ![Font Integration](../img/05-main-scene/special-win-font.png)
     3. Configure text alignment, font size, and spacing.
        - ![Font Layout](../img/05-main-scene/special-win-font-align.png)

**Tip**:
- Move assets to `custom-scale/` to resolve image quality issues.
- Customize font styles based on game design.
- [View Platform Asset Structure](/docs/category/game-asset-structure)